@@ -13,12 +13,12 @@ class SentryMixin(ConfigMixin):
 
     The `DJANGO_SENTRY_DSN` environment variable should be externally set to a Sentry DSN.
 
-    The `DJANGO_SENTRY_ENVIRONMENT` and `DJANGO_SENTRY_RELEASE` environment variables may also
-    be set, if desired.
+    The `DJANGO_SENTRY_ENVIRONMENT`, `DJANGO_SENTRY_RELEASE`, and `DJANGO_SENTRY_TRACES_SAMPLE_RATE`
+    environment variables may also be set, if desired.
     """
 
     @staticmethod
-    def before_binding(configuration: Type[ComposedConfiguration]) -> None:
+    def mutate_configuration(configuration: Type[ComposedConfiguration]) -> None:
         configuration.INSTALLED_APPS += [
             'composed_configuration.sentry.apps.SentryConfig',
         ]
@@ -28,3 +28,7 @@ class SentryMixin(ConfigMixin):
     SENTRY_ENVIRONMENT = values.Value(None)
 
     SENTRY_RELEASE = values.Value(None)
+
+    # None is a valid default value, but if this is set via environment variable,
+    # the value must be interpretable as a float
+    SENTRY_TRACES_SAMPLE_RATE = values.FloatValue(None)
